@@ -25,7 +25,6 @@
 #include <gio/gio.h>
 #include <string.h>
 
-#include "gnome-settings-plugin.h"
 #include "gnome-settings-profile.h"
 #include "gsd-rfkill-manager.h"
 #include "rfkill-glib.h"
@@ -60,6 +59,10 @@ struct GsdRfkillManagerPrivate
         gchar                   *chassis_type;
 };
 
+#define GSD_DBUS_NAME "org.gnome.SettingsDaemon"
+#define GSD_DBUS_PATH "/org/gnome/SettingsDaemon"
+#define GSD_DBUS_BASE_INTERFACE "org.gnome.SettingsDaemon"
+
 #define GSD_RFKILL_DBUS_NAME GSD_DBUS_NAME ".Rfkill"
 #define GSD_RFKILL_DBUS_PATH GSD_DBUS_PATH "/Rfkill"
 
@@ -279,6 +282,10 @@ rfkill_changed (CcRfkillGlib     *rfkill,
 				g_hash_table_insert (manager->priv->bt_killswitches,
 						     GINT_TO_POINTER (event->idx),
 						     GINT_TO_POINTER (value));
+			g_debug ("%s %srfkill with ID %d",
+				 event->op == RFKILL_OP_ADD ? "Added" : "Changed",
+				 event->type == RFKILL_TYPE_BLUETOOTH ? "Bluetooth " : "",
+				 event->idx);
                         break;
                 case RFKILL_OP_DEL:
 			g_hash_table_remove (manager->priv->killswitches,
@@ -286,6 +293,8 @@ rfkill_changed (CcRfkillGlib     *rfkill,
 			if (event->type == RFKILL_TYPE_BLUETOOTH)
 				g_hash_table_remove (manager->priv->bt_killswitches,
 						     GINT_TO_POINTER (event->idx));
+			g_debug ("Removed %srfkill with ID %d", event->type == RFKILL_TYPE_BLUETOOTH ? "Bluetooth " : "",
+				 event->idx);
                         break;
                 }
 	}
