@@ -45,7 +45,6 @@
 #include "gsd-enums.h"
 #include "gsd-input-helper.h"
 #include "gsd-keygrab.h"
-#include "gnome-settings-plugin.h"
 #include "gnome-settings-profile.h"
 #include "gnome-settings-bus.h"
 #include "gsd-wacom-manager.h"
@@ -81,6 +80,10 @@
 
 #define UNKNOWN_DEVICE_NOTIFICATION_TIMEOUT 15000
 
+#define GSD_DBUS_NAME "org.gnome.SettingsDaemon"
+#define GSD_DBUS_PATH "/org/gnome/SettingsDaemon"
+#define GSD_DBUS_BASE_INTERFACE "org.gnome.SettingsDaemon"
+
 #define GSD_WACOM_DBUS_PATH GSD_DBUS_PATH "/Wacom"
 #define GSD_WACOM_DBUS_NAME GSD_DBUS_NAME ".Wacom"
 
@@ -149,6 +152,8 @@ gsd_wacom_manager_class_init (GsdWacomManagerClass *klass)
 
         object_class->finalize = gsd_wacom_manager_finalize;
 
+        notify_init ("gnome-settings-daemon");
+
         g_type_class_add_private (klass, sizeof (GsdWacomManagerPrivate));
 }
 
